==> kdepim_4.8.4a.orig.tar.xz: kdepim-4.8.4/blogilo/src/waitwidget.cpp <==
/*
    This file is part of Blogilo, A KDE Blogging Client

    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
    Copyright (C) 2008-2010 Golnaz Nilieh <g382nilieh@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/
*/

#include "waitwidget.h"

#include <kdebug.h>

WaitWidget::WaitWidget(QWidget* parent ): QDialog(parent)
{
    kDebug();
    setupUi(this);
}

WaitWidget::~WaitWidget()
{
    kDebug();
}

void WaitWidget::setText( const QString& text )
{
    kDebug();
    operationNameLabel->setText( text );
    setWindowTitle( text );
}

void WaitWidget::setMaxJobs( int max )
{
    kDebug();
    progressBar->setMaximum( max );
}

void WaitWidget::jobDone()
{
    kDebug();
    progressBar->setValue(progressBar->value()+1);
}

void WaitWidget::setBusyState()
{
    progressBar->setMinimum( 0 );
    progressBar->setMaximum( 0 );
}

#include "waitwidget.moc"

==> kdepim-4.11.4.tar.xz: kdepim-4.11.4/blogilo/src/waitwidget.cpp <==
/*
    This file is part of Blogilo, A KDE Blogging Client

    Copyright (C) 2008-2010 Mehrdad Momeny <mehrdad.momeny@gmail.com>
    Copyright (C) 2008-2010 Golnaz Nilieh <g382nilieh@gmail.com>

    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of
    the License or (at your option) version 3 or any later version
    accepted by the membership of KDE e.V. (or its successor approved
    by the membership of KDE e.V.), which shall act as a proxy
    defined in Section 14 of version 3 of the license.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, see http://www.gnu.org/licenses/
*/

#include "waitwidget.h"

#include <kdebug.h>

WaitWidget::WaitWidget(QWidget* parent )
    : QDialog(parent)
{
    kDebug();
    setupUi(this);
}

WaitWidget::~WaitWidget()
{
    kDebug();
}

void WaitWidget::setText( const QString& text )
{
    kDebug();
    operationNameLabel->setText( text );
    setWindowTitle( text );
}

void WaitWidget::setMaxJobs( int max )
{
    kDebug();
    progressBar->setMaximum( max );
}

void WaitWidget::jobDone()
{
    kDebug();
    progressBar->setValue(progressBar->value()+1);
}

void WaitWidget::setBusyState()
{
    progressBar->setMinimum( 0 );
    progressBar->setMaximum( 0 );
}

#include "waitwidget.moc"
